Module docblock
mago_
syntax
1.27.1
Module docblock
Module Items
Structs
Functions
In mago_
syntax::
comments
mago_syntax
::
comments
Module
docblock
Structs

Preceding
Docblocks
An iterator that yields docblock trivia nodes preceding a position, walking backwards through stacked docblocks using the same gap-checking logic as
get_docblock_before_position
.
Functions

get_
docblock_
before_
position
Retrieves the docblock comment that appears before a specific position in the source code.
get_
docblock_
for_
node
Retrieves the docblock comment associated with a given node in the program. If the node is preceded by a docblock comment, it returns that comment.